import { ChainId } from "../common/chainid.js";
import { parseUnits } from "@ethersproject/units";
import { BigNumber } from "@ethersproject/bignumber";
export var GasUtils;
(function (GasUtils) {
    const makeGwei = (n) => parseUnits(n, "gwei");
    const CHAIN_GAS_PARAMS = {
        [ChainId.ETH]: {
            maxPriorityFee: makeGwei("1.5"),
            bridgeGasLimit: BigNumber.from(100000)
        },
        [ChainId.BOBA]: {
            gasPrice: makeGwei("10"),
            approveGasLimit: BigNumber.from(60000),
        },
        [ChainId.ARBITRUM]: {
            gasPrice: makeGwei("2.5"),
            bridgeGasLimit: BigNumber.from(1500000),
        },
        [ChainId.AVALANCHE]: {
            gasPrice: makeGwei("150"),
            bridgeGasLimit: BigNumber.from(800000),
            approveGasLimit: BigNumber.from(75000),
        },
        [ChainId.AURORA]: {
            gasPrice: makeGwei('1'),
        },
    };
    function makeGasParams(chainId) {
        return CHAIN_GAS_PARAMS[chainId] ?? {};
    }
    GasUtils.makeGasParams = makeGasParams;
    function populateGasParams(chainId, txn, gasLimitKind) {
        return Promise.resolve(txn)
            .then((tx) => {
            let { maxPriorityFee, gasPrice, approveGasLimit, bridgeGasLimit } = makeGasParams(chainId);
            if (gasPrice)
                tx.gasPrice = gasPrice;
            if (maxPriorityFee)
                tx.maxPriorityFeePerGas = maxPriorityFee;
            switch (gasLimitKind) {
                case "bridge":
                    if (bridgeGasLimit)
                        tx.gasLimit = bridgeGasLimit;
                    break;
                case "approve":
                    if (approveGasLimit)
                        tx.gasLimit = approveGasLimit;
                    break;
            }
            return tx;
        });
    }
    GasUtils.populateGasParams = populateGasParams;
})(GasUtils || (GasUtils = {}));
