import type { AddressMap, DecimalsMap } from "./common/types";
import type { ID, Entity } from "./internal/entity";
import type { SwapType } from "./internal/swaptype";
import { BigNumber, BigNumberish } from "@ethersproject/bignumber";
export interface IBaseToken extends Entity {
    readonly name: string;
    readonly symbol: string;
    readonly addresses: AddressMap;
    readonly swapType: SwapType;
    address: (chainId: number) => string | null;
    decimals: (chainId: number) => number | null;
}
export interface Token extends IBaseToken {
    isWrappedToken: boolean;
    underlyingToken?: Token;
    isEqual: (other: Token) => boolean;
    valueToWei: (amt: BigNumberish, chainId: number) => BigNumber;
    wrapperAddress: (chainId: number) => string | null;
}
export interface BaseTokenArgs {
    name: string;
    symbol: string;
    decimals: number | DecimalsMap;
    addresses: AddressMap;
    swapType: SwapType;
    isETH?: boolean;
    wrapperAddresses?: AddressMap;
}
export interface WrappedTokenArgs extends BaseTokenArgs {
    underlyingToken: BaseToken;
}
export declare class BaseToken implements Token {
    readonly id: ID;
    readonly name: string;
    readonly symbol: string;
    readonly addresses: AddressMap;
    readonly swapType: SwapType;
    readonly isETH: boolean;
    private readonly wrapperAddresses;
    protected readonly _decimals: DecimalsMap;
    constructor(args: BaseTokenArgs);
    address(chainId: number): string | null;
    wrapperAddress(chainId: number): string | null;
    decimals(chainId: number): number | null;
    isEqual(other: Token): boolean;
    valueToWei(ether: BigNumberish, chainId: number): BigNumber;
    get isWrappedToken(): boolean;
}
export declare class WrappedToken extends BaseToken {
    readonly underlyingToken: BaseToken;
    constructor(args: WrappedTokenArgs);
    get isWrappedToken(): boolean;
}
