import { parseUnits } from "@ethersproject/units";
import { BigNumber, } from "@ethersproject/bignumber";
export class BaseToken {
    id;
    name;
    symbol;
    addresses = {};
    swapType;
    isETH;
    wrapperAddresses = {};
    _decimals = {};
    constructor(args) {
        this.name = args.name;
        this.symbol = args.symbol;
        this.addresses = args.addresses;
        this.swapType = args.swapType;
        this.wrapperAddresses = args.wrapperAddresses ?? {};
        if (typeof args.decimals === "number") {
            for (const [k,] of Object.entries(this.addresses)) {
                this._decimals[k] = args.decimals;
            }
        }
        else {
            this._decimals = args.decimals;
        }
        this.isETH = args.isETH ?? false;
        this.id = Symbol(this.symbol);
    }
    address(chainId) {
        return this.addresses[chainId] || null;
    }
    wrapperAddress(chainId) {
        return this.wrapperAddresses[chainId] || null;
    }
    decimals(chainId) {
        return this._decimals[chainId] || null;
    }
    isEqual(other) {
        return this.id === other.id;
    }
    valueToWei(ether, chainId) {
        let etherStr = ether instanceof BigNumber
            ? ether.toString()
            : BigNumber.from(ether).toString();
        return parseUnits(etherStr, this.decimals(chainId));
    }
    get isWrappedToken() {
        return false;
    }
}
export class WrappedToken extends BaseToken {
    underlyingToken;
    constructor(args) {
        super(args);
        this.underlyingToken = args.underlyingToken;
    }
    get isWrappedToken() {
        return true;
    }
}
